Index: ui/events/blink/web_input_event_builders_win_unittest.cc |
diff --git a/ui/events/blink/web_input_event_builders_win_unittest.cc b/ui/events/blink/web_input_event_builders_win_unittest.cc |
index a9b92cb6549b5262a076d20a02fa67d54f82dc10..065c49ba5617aad411dcbc6007a410cfe379770d 100644 |
--- a/ui/events/blink/web_input_event_builders_win_unittest.cc |
+++ b/ui/events/blink/web_input_event_builders_win_unittest.cc |
@@ -33,15 +33,15 @@ TEST(WebInputEventBuilderTest, TestMouseEventScale) { |
::GetDesktopWindow(), WM_MOUSEMOVE, 0, MAKELPARAM(300, 200), 100, |
blink::WebPointerProperties::PointerType::Mouse); |
- // The WebMouseEvent.x, WebMouseEvent.y fields should be in pixels |
- // on return and hence should be the same value as the x and y coordinates |
- // passed in to the WebMouseEventBuilder::Build function. |
- EXPECT_EQ(300, mouse_move.x); |
- EXPECT_EQ(200, mouse_move.y); |
- |
- // WebMouseEvent.globalX and WebMouseEvent.globalY are calculated in DIPs. |
- EXPECT_EQ(150, mouse_move.globalX); |
- EXPECT_EQ(100, mouse_move.globalY); |
+ // The WebMouseEvent.position field should be in pixels on return and hence |
+ // should be the same value as the x and y coordinates passed in to the |
+ // WebMouseEventBuilder::Build function. |
+ EXPECT_EQ(300, mouse_move.positionInWidget().x); |
+ EXPECT_EQ(200, mouse_move.positionInWidget().y); |
+ |
+ // WebMouseEvent.positionInScreen is calculated in DIPs. |
+ EXPECT_EQ(150, mouse_move.positionInScreen().x); |
+ EXPECT_EQ(100, mouse_move.positionInScreen().y); |
EXPECT_EQ(blink::WebPointerProperties::PointerType::Mouse, |
mouse_move.pointerType); |